This folder contains official SMuFL metadata from https://github.com/w3c/smufl/tree/gh-pages/metadata

The files have been slightly modified so that the codepoints, written "U+0000" upstream, are written "\u0000". This allows direct use as unicode characters without preprocessing.
